@@ -113,13 +113,23 @@ notifyImport(int type, const char *message, void *data) {
 					break;
 				case TQSL_CERT_CB_ERROR:
 					if (message) {
-						// Suppress expiration message other than for user certs
-						if (strcmp(message, "certificate has expired") || TQSL_CERT_CB_CERT_TYPE(type) == TQSL_CERT_CB_USER) {
-							nd->status = nd->status + wxString::FromUTF8(message) + wxT("\n");
-							counts->error++;
+						switch (TQSL_CERT_CB_CERT_TYPE(type)) {
+							case TQSL_CERT_CB_ROOT:
+								nd->status = nd->status + _("Trusted root certificate");
+								break;
+							case TQSL_CERT_CB_CA:
+								nd->status = nd->status + _("Certificate Authority certificate");
+								break;
+							case TQSL_CERT_CB_USER:
+								nd->status = nd->status + _("Callsign Certificate");
+								break;
+						}
+						nd->status = nd->status + wxT(": ") + wxString::FromUTF8(message) + wxT("\n");
+						counts->error++;
+						if (TQSL_CERT_CB_CERT_TYPE(type) == TQSL_CERT_CB_USER) {
+							wxMessageBox(wxString::FromUTF8(message), _("Error"));
 						}
 					}
-					// wxMessageBox(wxString::FromUTF8(message), _("Error"));
 					break;
 				case TQSL_CERT_CB_LOADED:
 					if (TQSL_CERT_CB_CERT_TYPE(type) == TQSL_CERT_CB_USER)
@@ -148,15 +158,9 @@ GetNewPassword(char *buf, int bufsiz, void *) {
 	tqslTrace("GetNewPassword", NULL);
 	wxString msg = _("Enter a password for this callsign certificate.");
 		msg += wxT("\n\n");
-		msg += _("If you are using a computer system that is "
-			L"shared with others, you should specify a "
-			L"password to protect this certificate. However, if "
-			L"you are using a computer in a private residence "
-			L"no password need be specified.");
+		msg += _("If you are using a computer system that is shared with others, you should specify a password to protect this certificate. However, if you are using a computer in a private residence no password need be specified.");
 		msg += wxT("\n\n");
-		msg += _("This password will have to be entered each time "
-			L"you use this callsign certificate for signing or "
-			L"when saving the key.");
+		msg += _("This password will have to be entered each time you use this callsign certificate for signing or when saving the key.");
 		msg += wxT("\n\n");
 		msg += _("Leave the password blank and click 'OK' unless you want to use a password.");
 		msg += wxT("\n\n");
@@ -195,9 +199,7 @@ export_new_cert(ExtWizard *_parent, const char *filename) {
 				if (!tqsl_getCertificateSerial(cert, &serial)) {
 					if (serial == newserial) {
 						wxCommandEvent e;
-						wxString msg = _("You will not be able to use this tq6 file to recover your "
-							L"callsign certificate if it gets lost. For security purposes, you should "
-							L"back up your certificate on removable media for safe-keeping.");
+						wxString msg = _("You will not be able to use this tq6 file to recover your callsign certificate if it gets lost. For security purposes, you should back up your certificate on removable media for safe-keeping.");
 							msg += wxT("\n\n");
 							msg += _("Would you like to back up your callsign certificate now?");
 						if (wxMessageBox(msg, _("Warning"), wxYES_NO | wxICON_QUESTION, _parent) == wxNO) {
@@ -259,7 +261,8 @@ LoadCertWiz::LoadCertWiz(wxWindow *parent, wxHtmlHelpController *help, const wxS
 			_final->SetPrev(0);
 			if (tqsl_importTQSLFile(filename.ToUTF8(), notifyImport, GetNotifyData())) {
 				if (tQSL_Error != TQSL_CERT_ERROR) {  // if not already reported by the callback
-					wxMessageBox(getLocalizedErrorString(), _("Error"), wxOK | wxICON_ERROR, _parent);
+					//wxMessageBox(getLocalizedErrorString(), _("Error"), wxOK | wxICON_ERROR, _parent);
+					_nd->status = getLocalizedErrorString();
 				}
 			} else {
 				if (tQSL_ImportCall[0] != '\0') {
@@ -285,6 +288,9 @@ LoadCertWiz::LoadCertWiz(wxWindow *parent, wxHtmlHelpController *help, const wxS
 					_first = _p12pw;
 					_p12pw->SetPrev(0);
 					p12pw->SetFilename(filename);
+				} else if (tQSL_Error == TQSL_OPENSSL_ERROR) {
+					wxMessageBox(_("This file is not a valid P12 file"), _("Error"), wxOK | wxICON_ERROR, _parent);
+					_first = 0;	// Cancel
 				} else {
 					_first = 0;	// Cancel
 				}
@@ -357,6 +363,8 @@ LCW_P12PasswordPage::TransferDataFromWindow() {
 		if (tQSL_Error == TQSL_PASSWORD_ERROR) {
 			tc_status->SetLabel(_("Password error"));
 			return false;
+		} else if (tQSL_Error == TQSL_OPENSSL_ERROR) {
+			wxMessageBox(_("This file is not a valid P12 file"), _("Error"), wxOK | wxICON_ERROR, _parent);
 		} else {
 			wxMessageBox(getLocalizedErrorString(), _("Error"), wxOK | wxICON_ERROR, _parent);
 		}
